@@ -4,6 +4,8 @@
 #include <string>
 #include <stdexcept>
 
+namespace jags {
+
 class Function;
 
 /**
@@ -18,4 +20,6 @@ public:
     FuncError(Function const *func, std::string const &msg);
 };
 
+} /* namespace jags */
+
 #endif /* FUNC_ERROR_H_ */
