@@ -6,6 +6,7 @@
 
 using std::vector;
 
+namespace jags {
 namespace base {
 
 LessThan::LessThan () : Infix ("<")
@@ -22,4 +23,4 @@ bool LessThan::isDiscreteValued(vector<bool> const &mask) const
   return true;
 }
 
-}
+}}
