@@ -4,21 +4,26 @@
 #include <sampler/Slicer.h>
 #include <graph/Graph.h>
 
+namespace jags {
+    
+    class StochasticNode;
+    class SingletonGraphView;
+
 namespace base {
     
-/**
- * @short Discrete slice sampler
- *
- * Slice sampler for discrete valued distributions.
- *
- * To sample a discrete valued random variable X, we create an
- * auxiliary variable Y which is real valued, and for which p_[Y](y) =
- * p_[X](floor(y)).  Hence Y has a piecewise-constant density function
- * on the real line.  We sample Y and then set X = floor(Y).
- */
+    /**
+     * @short Discrete slice sampler
+     *
+     * Slice sampler for discrete valued distributions.
+     *
+     * To sample a discrete valued random variable X, we create an
+     * auxiliary variable Y which is real valued, and for which p_[Y](y) =
+     * p_[X](floor(y)).  Hence Y has a piecewise-constant density function
+     * on the real line.  We sample Y and then set X = floor(Y).
+     */
     class DiscreteSlicer : public Slicer {
-	GraphView const *_gv;
-	unsigned int _chain;
+	SingletonGraphView const *_gv;
+	const unsigned int _chain;
 	double _x;
     public:
 	/**
@@ -26,17 +31,16 @@ namespace base {
 	 * @param width Initial width of slice
 	 * @param ndoubles Maximum number of doublings of slice 
 	 */
-	DiscreteSlicer(GraphView const *gv, unsigned int chain,
+	DiscreteSlicer(SingletonGraphView const *gv, unsigned int chain,
                        double width=2, long ndoubles = 10);
 	void setValue(double x);
 	double value() const;
 	void getLimits(double *lower, double *upper) const;
 	void update(RNG*);
 	static bool canSample(StochasticNode const *node);
-	std::string name() const;
 	double logDensity() const;
     };
 
-}
+}}
 
 #endif /* DISCRETE_SLICER_H_ */
