@@ -19,6 +19,7 @@ using std::max_element;
 #define PROB(par) (par[0])
 #define NCAT(lengths) (lengths[0])
 
+namespace jags {
 namespace bugs {
 
 DCat::DCat()
@@ -117,7 +118,7 @@ bool DCat::isSupportFixed(vector<bool> const &fixmask) const
 
 bool DCat::checkParameterLength(vector<unsigned int> const &lengths) const
 {
-    return true;
+    return NCAT(lengths) > 0;
 }
 
 unsigned int DCat::length(vector<unsigned int> const &lengths) const
@@ -125,29 +126,29 @@ unsigned int DCat::length(vector<unsigned int> const &lengths) const
     return 1;
 }
 
-double DCat::KL(vector<double const *> const &par1,
-		vector<double const *> const &par2,
-		vector<unsigned int> const &lengths) const
-{
-    double psum1 = 0, psum2 = 0, y = 0;
-    for (unsigned int i = 0; i < NCAT(lengths); ++i) {
-	double p1 = PROB(par1)[i];
-	double p2 = PROB(par2)[i];
-	if (p1 == 0) {
-	    psum2 += p2;
-	}
-	else if (p2 == 0) {
-	    return JAGS_POSINF;
-	}
-	else {
-	    y += p1 * (log(p1) - log(p2));
-	    psum1 += p1;
-	    psum2 += p2;
+    double DCat::KL(vector<double const *> const &par0,
+		    vector<double const *> const &par1,
+		    vector<unsigned int> const &lengths) const
+    {
+	double psum0 = 0, psum1 = 0, y = 0;
+	for (unsigned int i = 0; i < NCAT(lengths); ++i) {
+	    double p0 = PROB(par0)[i];
+	    double p1 = PROB(par1)[i];
+	    if (p0 == 0) {
+		psum1 += p1;
+	    }
+	    else if (p1 == 0) {
+		return JAGS_POSINF;
+	    }
+	    else {
+		y += p0 * (log(p0) - log(p1));
+		psum0 += p0;
+		psum1 += p1;
+	    }
 	}
+	y /= psum0;
+	y -= (log(psum0) - log(psum1));
+	return y;
     }
-    y /= psum1;
-    y -= (log(psum1) - log(psum2));
-    return y;
-}
 
-}
+}}
