@@ -1,8 +1,9 @@
 #ifndef DDEXP_H_
 #define DDEXP_H_
 
-#include "RScalarDist.h"
+#include <distribution/RScalarDist.h>
 
+namespace jags {
 namespace bugs {
 
 /**
@@ -32,6 +33,6 @@ public:
 	    std::vector<double const *> const &par2) const;
 };
 
-}
+}}
 
 #endif /* DDEXP_H_ */
