@@ -3,6 +3,7 @@
 
 #include <function/ArrayFunction.h>
 
+namespace jags {
 namespace bugs {
     
     /**
@@ -18,10 +19,15 @@ namespace bugs {
 	bool checkParameterDim(std::vector<std::vector<unsigned int> > const 
 			       &dims) const;
 	std::vector<unsigned int> 
-	    dim(std::vector <std::vector<unsigned int> > const &dims) const;
+	    dim(std::vector <std::vector<unsigned int> > const &dims,
+		std::vector<double const *> const &values) const;
 	bool isDiscreteValued(std::vector<bool> const &mask) const;
+	bool isLinear(std::vector<bool> const &mask, 
+		      std::vector<bool> const &fixed) const;
+	bool isScale(std::vector<bool> const &mask, 
+		     std::vector<bool> const &fixed) const;
     };
     
-}
+}}
 
 #endif /* DSUM_FUNC_H_ */
