@@ -5,6 +5,7 @@
 
 using std::vector;
 
+namespace jags {
 namespace bugs {
 
     Inverse::Inverse (): ArrayFunction ("inverse", 1)
@@ -32,9 +33,10 @@ namespace bugs {
     }
 
     vector<unsigned int> 
-    Inverse::dim (vector<vector<unsigned int> > const &dims) const
+    Inverse::dim (vector<vector<unsigned int> > const &dims,
+		  vector<double const *> const &values) const
     {
 	return dims[0];
     }
 
-}
+}}
