@@ -1,5 +1,4 @@
 #include <config.h>
-#include <rng/RNG.h>
 
 #include <set>
 #include <vector>
@@ -14,10 +13,12 @@
 #include <graph/Graph.h>
 #include <graph/StochasticNode.h>
 #include <graph/DeterministicNode.h>
-#include <graph/LinkNode.h>
+//#include <graph/LinkNode.h>
 #include <distribution/Distribution.h>
 #include <rng/TruncatedNormal.h>
 #include <module/ModuleError.h>
+#include <util/logical.h>
+#include <rng/RNG.h>
 
 using std::string;
 using std::vector;
@@ -30,93 +31,110 @@ extern cholmod_common *glm_wk;
 namespace jags {
 
 static void getIndices(set<StochasticNode *> const &schildren,
-		       vector<StochasticNode *> const &rows,
+		       vector<StochasticNode *> const &allchildren,
+		       vector<unsigned int > const &allrows,
 		       vector<int> &indices)
 {
     indices.clear();
     
-    for (unsigned int i = 0; i < rows.size(); ++i) {
-	if (schildren.count(rows[i])) {
-	    indices.push_back(i);
+    for (unsigned int i = 0; i < allchildren.size(); ++i) {
+	if (schildren.count(allchildren[i])) {
+	    for (unsigned int j = allrows[i]; j < allrows[i+1]; ++j) {
+		indices.push_back(j);
+	    }
 	}
     }
-    
-    if (indices.size() != schildren.size()) {
-	throwLogicError("Size mismatch in getIndices");
-    }
 }
 
 namespace glm {
 
     void GLMMethod::calDesign() const
     {
+	if (allTrue(_fixed)) return; //Move along, nothing to see here
+	
 	vector<StochasticNode *> const &snodes = _view->nodes();
-	vector<StochasticNode *> const &schildren = 
-	    _view->stochasticChildren();
 
 	int *Xi = static_cast<int*>(_x->i);
 	int *Xp = static_cast<int*>(_x->p);
 	double *Xx = static_cast<double*>(_x->x);
 	
-	unsigned int nrow = schildren.size();
+	unsigned int nrow = _x->nrow;
 	unsigned int ncol = _view->length();
-	if (nrow != _x->nrow || ncol != _x->ncol) {
+	if (ncol != _x->ncol) {
 	    throwLogicError("Dimension mismatch in GLMMethod::calDesign");
 	}
 
 	int c = 0; //column counter
-	double *xnew = new double[_length_max];
+	vector<double> xnew(_length_max);
+
+	//Need to set up these vectors so we can map back from a row of
+	//the design matrix to the corresponding outcome. Note that this
+	//is only need when we have multivariate outcomes; with only
+	//scalar outcomes the mapping is trivial
+	vector<Outcome*> outcome_ptr(nrow);
+	vector<unsigned int> outcome_idx(nrow);
+	unsigned int r = 0; //row counter
+	for (unsigned int i = 0; i < _outcomes.size(); ++i) {
+	    for (unsigned int j = 0; j < _outcomes[i]->length(); ++j, ++r) {
+		outcome_ptr[r] = _outcomes[i];
+		outcome_idx[r] = j;
+	    }
+	}
 	
 	for (unsigned int i = 0; i < snodes.size(); ++i) {
 
 	    unsigned int length = snodes[i]->length();
 
-	    if (_init || !_fixed[i]) {
+	    if (!_fixed[i]) {
 
 		for (unsigned int j = 0; j < length; ++j) {
 		    for (int r = Xp[c+j]; r < Xp[c+j+1]; ++r) {
-			Xx[r] = -_outcomes[Xi[r]]->mean();
+			unsigned int row = Xi[r];
+			Xx[r] = - outcome_ptr[row]->vmean()[outcome_idx[row]];
 		    }
 		}
 		
 		double const *xold = snodes[i]->value(_chain);	    
-		copy(xold, xold + length, xnew);
+		copy(xold, xold + length, xnew.begin());
 		
 		for (unsigned int j = 0; j < length; ++j) {
-		    
 		    xnew[j] += 1;
-		    _sub_views[i]->setValue(xnew, length, _chain);
+		    _sub_views[i]->setValue(&xnew[0], length, _chain);
 		    for (int r = Xp[c+j]; r < Xp[c+j+1]; ++r) {
-			Xx[r] += _outcomes[Xi[r]]->mean();
+			unsigned int row = Xi[r];
+			Xx[r] += outcome_ptr[row]->vmean()[outcome_idx[row]];
 		    }
 		    xnew[j] -= 1;
 		}
-		_sub_views[i]->setValue(xnew, length, _chain);
+		_sub_views[i]->setValue(&xnew[0], length, _chain);
 	    }
 	    
 	    c += length;
 	}
-
-	delete [] xnew;
-	
     }
     
     GLMMethod::GLMMethod(GraphView const *view, 
 			 vector<SingletonGraphView const *> const &sub_views,
 			 vector<Outcome *> const &outcomes,
-			 unsigned int chain, bool link)
-	: _view(view), _chain(chain), _sub_views(sub_views), _outcomes(outcomes),
+			 unsigned int chain)
+	: _view(view), _chain(chain), _sub_views(sub_views),
+	  _outcomes(outcomes),
 	  _x(0), _factor(0), _fixed(sub_views.size(), false), 
-	  _length_max(0), _nz_prior(0), _init(true)
+	  _length_max(0), _nz_prior(0)
     {
 	view->checkFinite(chain); //Check validity of initial values
 	
 	vector<StochasticNode *> const &schildren = 
 	    view->stochasticChildren();
 
-	int nrow = schildren.size();
+	vector<unsigned int> rows(schildren.size() + 1);
+	rows[0] = 0;
+	for (unsigned int i = 0; i < schildren.size(); ++i) {
+	    rows[i+1] = rows[i] + schildren[i]->length();
+	}
 	int ncol = view->length();
-
+	int nrow = rows[schildren.size()];
+	
 	vector<int> Xp(ncol + 1);
 	vector<int> Xi;
     
@@ -129,7 +147,7 @@ namespace glm {
 	    children_p.insert(sub_views[p]->stochasticChildren().begin(),
 			      sub_views[p]->stochasticChildren().end());
 	    vector<int> indices;
-	    getIndices(children_p, schildren, indices);
+	    getIndices(children_p, schildren, rows, indices);
 
 	    unsigned int length = _sub_views[p]->length();
 	    for (unsigned int i = 0; i < length; ++i, ++c) {
@@ -155,9 +173,16 @@ namespace glm {
 	copy(Xp.begin(), Xp.end(), _xp);
 	copy(Xi.begin(), Xi.end(), _xi);
 
-	// Check for constant linear terms
+	// At this point, all elements of _fixed are set to false, so
+	// a call to calDesign calculates the whole design matrix
+	calDesign();
+	
+	// In future calls to calDesign, we do not want to recalculate
+	// fixed linear terms.
 	for (unsigned int i = 0; i < sub_views.size(); ++i) {
-	    _fixed[i] = checkLinear(sub_views[i], true, link);
+	    // FIXME: For future reference, we will need to make sure this
+	    // still works correctly for log-linear models.
+	    _fixed[i] = checkLinear(sub_views[i], true, true);
 	}
     }
 
@@ -215,6 +240,7 @@ namespace glm {
 	// Likelihood contribution
     
 	cholmod_sparse *t_x = cholmod_transpose(_x, 0, glm_wk);
+	cholmod_sort(t_x, glm_wk);
 	cholmod_sparse *Alik = cholmod_aat(t_x, 0, 0, 0, glm_wk);
 	cholmod_sparse *A = cholmod_add(Aprior, Alik, 0, 0, 0, 0, glm_wk);
 
@@ -290,193 +316,106 @@ namespace glm {
 	//   - mu is the mean of the stochastic children
 	//   - Y is the value of the stochastic children
 
+	/* FIXME: We can also transpose _x into a pre-defined sparse
+	   matrix. Try this with the lsat example to see what speed-up
+	   it gives.
+	*/
 	cholmod_sparse *t_x = cholmod_transpose(_x, 1, glm_wk);
+	cholmod_sort(t_x, glm_wk); //Needed for multivariate outcomes
+	
 	int *Tp = static_cast<int*>(t_x->p);
 	int *Ti = static_cast<int*>(t_x->i);
 	double *Tx = static_cast<double*>(t_x->x);
 
+	/*
 	//FIXME: reusing previously defined c,r here
 	for (c = 0; c < t_x->ncol; ++c) {
 	    double tau = _outcomes[c]->precision();
 	    double delta = tau * (_outcomes[c]->value() - _outcomes[c]->mean());
-	    double sigma = sqrt(tau);
+	    //double sigma = sqrt(tau);
 	    for (r = Tp[c]; r < Tp[c+1]; ++r) {
 		b[Ti[r]] += Tx[r] * delta;
-		Tx[r] *= sigma;
+		//Tx[r] *= sigma;
+		Tx[r] *= tau;
 	    }
 	}
+	*/
+	
+	//FIXME: reusing previously defined c,r here
+	c = 0;
+	for (unsigned int i = 0; i < _outcomes.size(); ++i) {
+	    unsigned int m = _outcomes[i]->length();
+	    if (m == 1) {
+		//Scalar outcome
+		double tau = _outcomes[i]->precision();
+		double delta = tau * (_outcomes[i]->value() -
+				      _outcomes[i]->mean());
+		for (r = Tp[c]; r < Tp[c+1]; ++r) {
+		    b[Ti[r]] += Tx[r] * delta;
+		    Tx[r] *= tau;
+		}
+	    }
+	    else {
+		//Multivariate outcome
+		double const *tau = _outcomes[i]->vprecision();
+		double const *Y = _outcomes[i]->vvalue();
+		double const *mu = _outcomes[i]->vmean();
 
-	cholmod_sparse *Alik = cholmod_aat(t_x, 0, 0, 1, glm_wk);
+		vector<double> delta(m,0);
+		for (unsigned int j = 0; j < m; ++j) {
+		    for (unsigned int k = 0; k < m; ++k) {
+			delta[j] += tau[m*j+k] * (Y[k] - mu[k]);
+		    }
+		}
+
+		/* Sanity checks */
+		int nzrow = Tp[c+1] - Tp[c];
+		for (r = Tp[c]; r < Tp[c+1]; ++r) {
+		    int row = Ti[r];
+		    for (unsigned int j = 0; j < m; ++j) {
+			unsigned int col = c + j;
+			if (Tp[col+1] - Tp[col] != nzrow) {
+			    string ms("non-zero pattern mismatch in GLMMethod");
+			    throwLogicError(ms);
+			}
+			if (Ti[r+j*nzrow] != row) {
+			    string ms("row order mismatch in GLMMethod");
+			    throwLogicError(ms);
+			}
+		    }
+		}
+
+		/* We assume that all columns of t_x corresponding to
+		   the same outcome have the same non-zero pattern
+		   and the columns are sorted.
+		*/
+		vector<double> TxTau(m); // t_x %*% tau
+		for (r = Tp[c]; r < Tp[c+1]; ++r) {
+		    for (unsigned int j = 0; j < m; ++j) {
+			b[Ti[r]] += Tx[r + j*nzrow] * delta[j];
+			TxTau[j] = 0.0;
+			for (unsigned int k = 0; k < m; ++k) {
+			    TxTau[j] += Tx[r + k*nzrow] * tau[m*j+k];
+			}
+		    }
+		    for (unsigned int j = 0; j < m; ++j) {
+			Tx[r + j*nzrow] = TxTau[j];
+		    }
+		}
+	    }
+	    c += m;
+	}
+	
+	cholmod_sparse *Alik = cholmod_ssmult(t_x, _x, CHOLMOD_REAL, 1, 0,
+					      glm_wk);
 	cholmod_free_sparse(&t_x, glm_wk);
 	double one[2] = {1, 0};
 	A = cholmod_add(Aprior, Alik, one, one, 1, 0, glm_wk);
-	A->stype = -1;
+
 	cholmod_free_sparse(&Aprior, glm_wk);
 	cholmod_free_sparse(&Alik, glm_wk);
     }
 
-    void GLMMethod::updateLM(RNG *rng, bool stochastic) 
-    {
-	//   The log of the full conditional density takes the form
-	//   -(t(x) %*% A %*% x - 2 * b %*% x)/2
-	//   where A is the posterior precision and the mean mu solves
-	//   A %*% mu = b
-
-	//   For computational convenience we take xold, the current value
-	//   of the sampled nodes, as the origin
-
-	if (_init) {
-	    calDesign();
-	    symbolic();
-	    _init = false;
-	}
-
-	double *b = 0;
-	cholmod_sparse *A = 0;
-	calCoef(b, A);
-	
-	// Get LDL' decomposition of posterior precision
-	A->stype = -1;
-	int ok = cholmod_factorize(A, _factor, glm_wk);
-	cholmod_free_sparse(&A, glm_wk);
-	if (!ok) {
-	    throwRuntimeError("Cholesky decomposition failure in GLMMethod");
-	}
-
-	// Use the LDL' decomposition to generate a new sample
-	// with mean mu such that A %*% mu = b and precision A. 
-	
-	unsigned int nrow = _view->length();
-	cholmod_dense *w = cholmod_allocate_dense(nrow, 1, nrow, CHOLMOD_REAL, 
-						  glm_wk);
-
-	// Permute RHS
-	double *wx = static_cast<double*>(w->x);
-	int *perm = static_cast<int*>(_factor->Perm);
-	for (unsigned int i = 0; i < nrow; ++i) {
-	    wx[i] = b[perm[i]];
-	}
-
-	cholmod_dense *u1 = cholmod_solve(CHOLMOD_L, _factor, w, glm_wk);
-	updateAuxiliary(u1, _factor, rng);
-
-	if (stochastic) {
-	    double *u1x = static_cast<double*>(u1->x);
-	    if (_factor->is_ll) {
-		// LL' decomposition
-		for (unsigned int r = 0; r < nrow; ++r) {
-		    u1x[r] += rng->normal();
-		}
-	    }
-	    else {
-		// LDL' decomposition. The diagonal D matrix is stored
-		// as the diagonal of _factor
-		int *fp = static_cast<int*>(_factor->p);
-		double *fx = static_cast<double*>(_factor->x);
-		for (unsigned int r = 0; r < nrow; ++r) {
-		    u1x[r] += rng->normal() * sqrt(fx[fp[r]]);
-		}
-	    }
-	}
-
-	cholmod_dense *u2 = cholmod_solve(CHOLMOD_DLt, _factor, u1, glm_wk);
-
-	// Permute solution
-	double *u2x = static_cast<double*>(u2->x);
-	for (unsigned int i = 0; i < nrow; ++i) {
-	    b[perm[i]] = u2x[i];
-	}
-
-	cholmod_free_dense(&w, glm_wk);
-	cholmod_free_dense(&u1, glm_wk);
-	cholmod_free_dense(&u2, glm_wk);
-
-	//Shift origin back to original scale
-	int r = 0;
-	for (vector<StochasticNode*>::const_iterator p = 
-		 _view->nodes().begin();  p != _view->nodes().end(); ++p)
-	{
-	    unsigned int length = (*p)->length();
-	    double const *xold = (*p)->value(_chain);
-	    for (unsigned int i = 0; i < length; ++i, ++r) {
-		b[r] += xold[i];
-	    }
-	}
-
-	_view->setValue(b, nrow, _chain);
-	delete [] b;
-    }
-
-    void GLMMethod::updateLMGibbs(RNG *rng) 
-    {
-	// Update element-wise. Less efficient than updateLM but
-	// does not require a Cholesky decomposition, and is 
-	// necessary for truncated parameters
-
-	if (_init) {
-	    if (_view->length() != _sub_views.size()) {
-		throwLogicError("updateLMGibbs can only act on scalar nodes");
-	    }
-	    calDesign();
-	    _init = false;
-	}
-
-	double *b = 0;
-	cholmod_sparse *A = 0;
-	calCoef(b, A);
-
-	int nrow = _view->length();
-	vector<double> theta(nrow);
-	_view->getValue(theta, _chain);
-
-	int *Ap = static_cast<int*>(A->p);
-	int *Ai = static_cast<int*>(A->i);
-	double *Ax = static_cast<double*>(A->x);
-
-	//Extract diagonal from A
-	vector<double> diagA(nrow);
-	for (int c = 0; c < nrow; ++c) {
-	    for (int j = Ap[c]; j < Ap[c+1]; ++j) {
-		if (Ai[j] == c) {
-		    diagA[c] = Ax[j];
-		    break;
-		}
-	    }
-	}
-
-	//Update element-wise
-	for (int i = 0; i < nrow; ++i) {
-	    
-	    double theta_old = theta[i];
-		
-	    double mu  = theta[i] + b[i]/diagA[i];
-	    double sigma = sqrt(1/diagA[i]);
-	    StochasticNode const *snode = _sub_views[i]->nodes()[0];
-	    double const *l = snode->lowerLimit(_chain);
-	    double const *u = snode->upperLimit(_chain);
-		
-	    if (l && u) {
-		theta[i] = inormal(*l, *u, rng, mu, sigma);
-	    }
-	    else if (l) {
-		theta[i] = lnormal(*l, rng, mu, sigma);
-	    }
-	    else if (u) {
-		theta[i] = rnormal(*u, rng, mu, sigma);
-	    }
-	    else {
-		theta[i] = mu + rng->normal() * sigma;
-	    }
-		
-	    double delta = theta[i] - theta_old;
-	    for (int j = Ap[i]; j < Ap[i+1]; ++j) {
-		b[Ai[j]] -= delta * Ax[j];
-	    }
-	}
-
-	_view->setValue(theta,  _chain);
-    }
-
     bool GLMMethod::isAdaptive() const
     {
 	return false;
@@ -491,8 +430,4 @@ namespace glm {
 	return true;
     }
 
-    void GLMMethod::updateAuxiliary(cholmod_dense *b, cholmod_factor *N, RNG *rng)
-    {
-    }
-
 }}
