@@ -3,6 +3,7 @@
 
 #include <sampler/SamplerFactory.h>
 
+namespace jags {
 namespace mix {
 
 /**
@@ -11,14 +12,14 @@ namespace mix {
     class MixSamplerFactory : public SamplerFactory
     {
     public:
-	Sampler * makeSampler(std::set<StochasticNode*> const &nodes, 
+	Sampler * makeSampler(std::list<StochasticNode*> const &nodes, 
 			      Graph const &graph) const;
 	std::vector<Sampler*>  
-	    makeSamplers(std::set<StochasticNode*> const &nodes, 
+	    makeSamplers(std::list<StochasticNode*> const &nodes, 
 			 Graph const &graph) const;
 	std::string name() const;
     };
 
-}
+}}
 
 #endif /* MIX_SAMPLER_FACTORY_H_ */
